@@ -6,7 +6,7 @@ from urllib.parse import urlparse
 
 class Util:
     @staticmethod
-    def relative_files_from_dir(directory: str):
+    def relative_files_from_dir(directory: str) -> dict:
         abspath = os.path.abspath(directory)
         parent = Path(abspath).parent
         glob_string = f"{abspath}/**/*"
@@ -20,11 +20,11 @@ class Util:
         return results
 
     @staticmethod
-    def get_bucket_and_prefix_from_url(url):
+    def get_bucket_and_prefix_from_url(url: str):
         o = urlparse(url)
         return o.scheme, o.netloc, o.path.lstrip("/")
 
-    def _remove_prefix(text, prefix):
+    def _remove_prefix(text: str, prefix: str) -> str:
         if text.startswith(prefix):
             return text[len(prefix) :]
         return text
